==> moodle_1.3.1.orig.tar.gz: moodle/lang/pl/calendar.php <==
<?PHP // $Id: calendar.php,v 1.1 2004/05/24 09:54:13 adamtpaw Exp $ 
      // calendar.php - created with Moodle 1.3 development (2004040500)


$string['april'] = 'Kwiecie';
$string['august'] = 'Sierpie';
$string['calendar'] = 'Kalendarz';
$string['calendarheading'] = 'Kalendarz $a';
$string['clickhide'] = 'Ukryj';
$string['clickshow'] = 'Poka';
$string['confirmeventdelete'] = 'Czy jeste pewien, e chcesz usun ten termin?';
$string['courseevents'] = 'Terminy kursu';
$string['dayview'] = 'Widok dnia';
$string['daywithnoevents'] = 'Nie ma adnych terminw do wywietlenia w tym widoku';
$string['december'] = 'Grudzie';
$string['default'] = 'Domylna/e';
$string['deleteevent'] = 'Usu termin';
$string['detailedmonthview'] = 'Szczegowy widok miesica';
$string['durationnone'] = 'Bez okresu trwania';
$string['durationuntil'] = 'A do';
$string['editevent'] = 'Edycja terminu';
$string['errorbeforecoursestart'] = 'Nie mona zapisa tego terminu przed dat rozpoczcia kursu';
$string['errorinvaliddate'] = 'Nieprawidowa data';
$string['errornodescription'] = 'Musisz wpisa opis terminu';
$string['errornoeventname'] = 'Imi jest wymagane';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Opis';
$string['eventduration'] = 'Okres';
$string['eventendtime'] = 'Data kocowa';
$string['eventinstanttime'] = 'Czas';
$string['eventkind'] = 'Typ terminu';
$string['eventname'] = 'Imi';
$string['eventsfor'] = 'Terminy $a';
$string['eventstarttime'] = 'Czas pocztkowy';
$string['eventtime'] = 'Czas';
$string['eventview'] = 'Szczegy terminu';
$string['expired'] = 'Wygasy(a)';
$string['explain_lookahead'] = 'Ten parametr oznacza maksymaln liczb dni \"na przyszo\" na podstawie ktrej okrelony termin zostanie wywietlony jako nadchodzcy. Terminy ustalone jako rozpoczynajce si pniej w stosunku do tej iloci dni nie bd wywietlone. Zauwa, e <strong>nie ma gwarancji</strong>, e wszystkie zdarzenia zaczynajce si w danym przecigu czasu bd wywietlone jako nadchodzce; jeli jest ich zbyt wiele, najbardziej oddalone zdarzenia nie zostana wywietlone. ';
$string['explain_maxevents'] = 'Ten parametr ustala maksymaln liczb wydarze, ktre zostan wywietlone.';
$string['explain_startwday'] = 'Ten parametr ustawia sposb w jaki wszystkie miesiczne kalendarze bd wywietlone. Ustaw go w sposb do ktrego jeste przyzwyczajony.';
$string['february'] = 'Luty';
$string['fri'] = 'Pi.';
$string['friday'] = 'Pitek';
$string['globalevents'] = 'Terminy globalne';
$string['groupevents'] = 'Terminy grupowe';
$string['hidden'] = 'ukryty';
$string['january'] = 'Stycze';
$string['july'] = 'Lipiec';
$string['june'] = 'Czerwiec';
$string['manyevents'] = 'Terminy $a';
$string['march'] = 'Marzec';
$string['may'] = 'Maj';
$string['mon'] = 'Pn';
$string['monday'] = 'Poniedziaek';
$string['monthlyview'] = 'Widok miesica';
$string['newevent'] = 'Nowy termin';
$string['november'] = 'Listopad';
$string['october'] = 'Padziernik';
$string['oneevent'] = '1 termin';
$string['pref_lookahead'] = 'Nadchodzce spotkania';
$string['pref_maxevents'] = 'Maximum nadchodzcych spotka';
$string['pref_startwday'] = 'Pierwszy dzie tygodnia';
$string['preferences'] = 'Preferencje';
$string['preferences_available'] = 'Twoje osobiste preferencje';
$string['sat'] = 'So.';
$string['saturday'] = 'Sobota';
$string['september'] = 'Wrzesie';
$string['shown'] = 'pokazane';
$string['spanningevents'] = 'Biece terminy';
$string['sun'] = 'Ni.';
$string['sunday'] = 'Niedziela';
$string['thu'] = 'Cz.';
$string['thursday'] = 'Czwartek';
$string['today'] = 'Dzi';
$string['tomorrow'] = 'Jutro';
$string['tt_deleteevent'] = 'Usu';
$string['tt_editevent'] = 'Edytuj';
$string['tt_hidecourse'] = 'Terminy kursu (kliknij aby ukry)';
$string['tt_hideglobal'] = 'Terminy globalne (kliknij aby ukry)';
$string['tt_hidegroups'] = 'Terminy grupowe(kliknij aby ukry)';
$string['tt_hideuser'] = 'Terminy uytkownika (kliknij aby ukry)';
$string['tt_showcourse'] = 'Terminy kursu (kliknij aby pokaza)';
$string['tt_showglobal'] = 'Terminy globalne (kliknij aby pokaza)';
$string['tt_showgroups'] = 'Terminy grupowe (kliknij aby pokaza)';
$string['tt_showuser'] = 'Terminy uytkownika (kliknij aby pokaza)';
$string['tue'] = 'Wt.';
$string['tuesday'] = 'Wtorek';
$string['typecourse'] = 'Termin kursu';
$string['typegroup'] = 'Termin grupowy';
$string['typesite'] = 'Termin strony';
$string['typeuser'] = 'Termin uytkownika';
$string['upcomingevents'] = 'Nadchodzce terminy';
$string['userevents'] = 'Terminy uytkownika';
$string['wed'] = 'r.';
$string['wednesday'] = 'roda';
$string['yesterday'] = 'Wczoraj';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pl/calendar.php <==
<?PHP // $Id$ 
      // calendar.php - created with Moodle 1.4 (2004083100)


$string['calendar'] = 'Kalendarz';
$string['calendarheading'] = 'Kalendarz $a';
$string['clickhide'] = 'ukryj';
$string['clickshow'] = 'poka';
$string['confirmeventdelete'] = 'Czy jeste pewien, e chcesz usun ten termin?';
$string['courseevents'] = 'Terminy kursu';
$string['dayview'] = 'Widok dnia';
$string['daywithnoevents'] = 'Nie ma adnych terminw do wywietlenia w tym widoku';
$string['default'] = 'Domylna/e';
$string['deleteevent'] = 'Usu termin';
$string['detailedmonthview'] = 'Szczegowy widok miesica';
$string['durationminutes'] = 'Czas w minutach';
$string['durationnone'] = 'Bez okresu trwania';
$string['durationuntil'] = 'A do';
$string['editevent'] = 'Edycja terminu';
$string['errorbeforecoursestart'] = 'Nie mona zapisa tego terminu przed dat rozpoczcia kursu';
$string['errorinvaliddate'] = 'Nieprawidowa data';
$string['errorinvalidminutes'] = 'Okrel czas trwania w minutach podajc liczb pomidzy 1 i 999';
$string['errorinvalidrepeats'] = 'Okrel ilo spotka podajc liczb pomidzy 1 i 999';
$string['errornodescription'] = 'Musisz wpisa opis terminu';
$string['errornoeventname'] = 'Nazwa jest wymagana';
$string['eventdate'] = 'Data';
$string['eventdescription'] = 'Opis';
$string['eventduration'] = 'Okres';
$string['eventendtime'] = 'Data kocowa';
$string['eventinstanttime'] = 'Czas';
$string['eventkind'] = 'Typ terminu';
$string['eventname'] = 'Nazwa';
$string['eventrepeat'] = 'Powtrzenia';
$string['eventsfor'] = 'Terminy $a';
$string['eventstarttime'] = 'Czas pocztkowy';
$string['eventtime'] = 'Czas';
$string['eventview'] = 'Szczegy terminu';
$string['expired'] = 'Wygasy(a)';
$string['explain_lookahead'] = 'Ten parametr oznacza maksymaln liczb dni \"na przyszo\" na podstawie ktrej okrelony termin zostanie wywietlony jako nadchodzcy. Terminy ustalone jako rozpoczynajce si pniej w stosunku do tej iloci dni nie bd wywietlone. Zauwa, e <strong>nie ma gwarancji</strong>, e wszystkie zdarzenia zaczynajce si w danym przecigu czasu bd wywietlone jako nadchodzce; jeli jest ich zbyt wiele, najbardziej oddalone zdarzenia nie zostana wywietlone. ';
$string['explain_maxevents'] = 'Ten parametr ustala maksymaln liczb wydarze, ktre zostan wywietlone.';
$string['explain_startwday'] = 'Ten parametr ustawia sposb w jaki wszystkie miesiczne kalendarze bd wywietlone. Ustaw go w sposb do ktrego jeste przyzwyczajony.';
$string['explain_timeformat'] = 'Moesz wybra czas w formacie 12 albo 24 godzinnym. Jeli wybierzesz \"domylny\", wwczas ten format bdzie automatycznie wybrany w zgodzie z jzykiem, ktry uywasz na tej stronie';
$string['fri'] = 'Pi.';
$string['friday'] = 'Pitek';
$string['globalevents'] = 'Terminy globalne';
$string['gotocalendar'] = 'Przejd do kalendarza';
$string['groupevents'] = 'Terminy grupowe';
$string['hidden'] = 'ukryty';
$string['manyevents'] = 'Terminy $a';
$string['mon'] = 'Pn.';
$string['monday'] = 'Poniedziaek';
$string['monthlyview'] = 'Widok miesica';
$string['newevent'] = 'Nowy termin';
$string['noupcomingevents'] = 'Brak nadchodzcych spotka';
$string['oneevent'] = '1 termin';
$string['pref_lookahead'] = 'Nadchodzce spotkania';
$string['pref_maxevents'] = 'Maximum nadchodzcych spotka';
$string['pref_startwday'] = 'Pierwszy dzie tygodnia';
$string['pref_timeformat'] = 'Format wywietlenia czasu';
$string['preferences'] = 'Preferencje';
$string['preferences_available'] = 'Twoje osobiste preferencje';
$string['repeatnone'] = 'Brak powtrze';
$string['repeatweeksl'] = 'Powtrz co tydzie';
$string['repeatweeksr'] = 'Spotkania';
$string['sat'] = 'So.';
$string['saturday'] = 'Sobota';
$string['shown'] = 'pokazane';
$string['spanningevents'] = 'Biece terminy';
$string['sun'] = 'Ni.';
$string['sunday'] = 'Niedziela';
$string['thu'] = 'Cz.';
$string['thursday'] = 'Czwartek';
$string['timeformat_12'] = '12-godzinny (am/pm)';
$string['timeformat_24'] = '24-godzinny';
$string['today'] = 'Dzi';
$string['tomorrow'] = 'Jutro';
$string['tt_deleteevent'] = 'Usu';
$string['tt_editevent'] = 'Edytuj';
$string['tt_hidecourse'] = 'Terminy kursu (kliknij aby ukry)';
$string['tt_hideglobal'] = 'Terminy globalne (kliknij aby ukry)';
$string['tt_hidegroups'] = 'Terminy grupowe(kliknij aby ukry)';
$string['tt_hideuser'] = 'Terminy uytkownika (kliknij aby ukry)';
$string['tt_showcourse'] = 'Terminy kursu (kliknij aby pokaza)';
$string['tt_showglobal'] = 'Terminy globalne (kliknij aby pokaza)';
$string['tt_showgroups'] = 'Terminy grupowe (kliknij aby pokaza)';
$string['tt_showuser'] = 'Terminy uytkownika (kliknij aby pokaza)';
$string['tue'] = 'Wt.';
$string['tuesday'] = 'Wtorek';
$string['typecourse'] = 'Termin kursu';
$string['typegroup'] = 'Termin grupowy';
$string['typesite'] = 'Termin strony';
$string['typeuser'] = 'Termin uytkownika';
$string['upcomingevents'] = 'Nadchodzce terminy';
$string['userevents'] = 'Terminy uytkownika';
$string['wed'] = 'r.';
$string['wednesday'] = 'roda';
$string['yesterday'] = 'Wczoraj';

?>
